@@ -1,7 +1,7 @@
 test_that("stan respects changes to control parameters", {
-  lodder <- lodder_sub()
+  mpm <- money_priming_sub()
 
-  res <- phacking_rtma(lodder$yi, lodder$vi, alpha_select = 1e-10,
+  res <- phacking_meta(mpm$yi, mpm$vi, alpha_select = 1e-10,
                        parallelize = FALSE,
                        stan_control = list(adapt_delta = 0.7,
                                            max_treedepth = 10))
@@ -12,21 +12,20 @@ test_that("stan respects changes to control parameters", {
 })
 
 test_that("study counts are right even with a strange alpha_select", {
-  lodder <- lodder_sub()
+  mpm <- money_priming_sub()
   alpha <- 1e-10
   z_alpha <- qnorm(1 - alpha / 2)
-  lodder$my_affirm <- lodder$yi / sqrt(lodder$vi) > z_alpha
-  res <- phacking_rtma(lodder$yi, lodder$vi, alpha_select = alpha,
+  mpm <- mpm |> mutate(affirm = yi / sqrt(vi) > z_alpha)
+  res <- phacking_meta(mpm$yi, mpm$vi, alpha_select = alpha,
                        parallelize = FALSE)
 
-  expect_equal(nrow(lodder), res$values$k)
-  expect_equal(sum(lodder$my_affirm), res$values$k_affirmative)
-  expect_equal(sum(lodder$my_affirm == 0), res$values$k_nonaffirmative)
-  expect_equal(z_alpha, res$values$tcrit)
+  expect_equal(nrow(mpm), res$values$k)
+  expect_equal(sum(mpm$affirm), res$values$k_affirmative)
+  expect_equal(sum(mpm$affirm == 0), res$values$k_nonaffirmative)
 })
 
 test_that("one nonaffirmative runs", {
   # try passing only 1 nonaffirmative; should still run but have warnings
-  w <- capture_warnings(phacking_rtma(yi = 0.2, sei = 0.2, parallelize = FALSE))
+  w <- capture_warnings(phacking_meta(yi = 0.2, sei = 0.2, parallelize = FALSE))
   expect_gt(length(w), 0)
 })
